/* event.h
 * Implement an event class for windows
 * Copyright Michel Leunen 2003
 * http://www.leunen.com/
 * michel@leunen.com
 *
 * This software is freeware and is provided at no charge to the user.
 * This software is provided 'as-is', without any express or implied warranty.
 * To the maximum extent permitted by applicable law will the author NOT be held
 * liable for any damages whatsoever arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose, including
 * commercial applications, and to freely redistribute it, with the following
 * restrictions:
 *
 * 1. If you use this software in a product, an acknowledgment in the product
 *    documentation would be appreciated.
 *
 * 2. If you use this software in a commercial application, please send me an email
 *	  detailing the application.
 *
 * 3. This notice may not be removed or altered from any source distribution.
 *
 * 4. It may be distributed by any means, provided that the original files
 * 		as supplied by the author remain intact and no charge is made other than
 * 		for reasonable distribution costs. If you are a vendor, if you want to
 * 		include this software in a compilation or in a magazine cover disk
 * 		you HAVE TO CONTACT ME to obtain my authorization before distribution.
 */

#ifndef EVENT_H
#define EVENT_H

#include <windows.h>
//------------------------------------------------------------
namespace mlLib
{

class Event
{
	private:
		HANDLE handle_;
		Event(const Event&);
		Event& operator=(const Event&);
	public:
      Event()
      {
        // Create event in non-signaled state and manual reset after every Wait
        handle_=CreateEvent(NULL,true,false,NULL);
      }
      ~Event()
      {
        CloseHandle(handle_);
      }
      // Put event into signaled state
      bool Set(){return SetEvent(handle_);}
      // Put event into non-signaled state
      bool Reset(){return ResetEvent(handle_;}
      // Wait until event is in signaled state
      DWORD WaitFor(DWORD delay=INFINITE)
      {
        // Wait until event is in signaled state
        DWORD res=WaitForSingleObject(handle_,delay);
        ResetEvent(handle_);
        return res;
      }
      HANDLE Handle()const{return handle_;}
      operator bool()const{return handle_!=HANDLE(NULL);}
};

} //end namespace mlLib
#endif
